diff --git a/src/interaction/prostheticConfig.tw b/src/interaction/prostheticConfig.tw
index 2333878bf23caa94140c5551bef7218132945df2..3dc2e40418f96e637ab78b494799e56b0ebb0c4d 100644
--- a/src/interaction/prostheticConfig.tw
+++ b/src/interaction/prostheticConfig.tw
@@ -266,7 +266,7 @@ This room is lined with shelves and cabinets; it could be easily mistaken for a
 	<div>''Buy and fit''</div>
 	<div>
 		<<if $researchLab.level > 0>>
-			<<= App.UI.disabledLink(`''Construct in lab''`, ["Depending on lab speed, it might be faster than fitting an existing prosthetic but should almost always be faster than first building and than fitting it to $him."])>>
+			<<= App.UI.disabledLink(`''Construct in lab''`, ["Depending on lab speed, it might be faster than fitting an existing prosthetic but should almost always be faster than first building and then fitting it to $him."])>>
 		<<else>>
 			<<= App.UI.disabledLink(`''Construct in lab''`, ["With a lab you could both increase speed and decrease cost."])>>
 		<</if>>
diff --git a/src/npc/descriptions/limbs.js b/src/npc/descriptions/limbs.js
index c54e253ae1c7294e701d0c9df5a7761ab19f5e7d..f1682d5d02292433d7eac395f44664ba13a0c23b 100644
--- a/src/npc/descriptions/limbs.js
+++ b/src/npc/descriptions/limbs.js
@@ -76,7 +76,7 @@ App.Desc.limbChange = function() {
 		if (implant) {
 			return "<span id='amputate'>" +
 				`<div>Since you already have a prosthetic interface prepared for this slave, you can install it during the operation. The procedure will put additional strain on ${his} health but less so than if you were to perform the procedures separately.</div>` +
-				`${r}<div>${App.UI.link("Do not install", noInstall())}</div></span>`;
+				`${r}<div>${App.UI.link("Do not install", noInstall)}</div></span>`;
 		}
 
 		if (slave.PLimb > 0) {
@@ -106,7 +106,7 @@ App.Desc.limbChange = function() {
 	}
 
 	/**
 	 * Displays a selector for prosthetic limbs of $activeSlave
 	 * @param {App.Entity.SlaveState} slave
 	 * @param {{}} oldLimbs
 	 * @param {string} [returnTo]
@@ -187,10 +187,10 @@ App.Desc.limbChange = function() {
 				s = `<<set $prostheticsConfig = "limbs", $oldLimbs = ${JSON.stringify(oldLimbs)}>>` +
 					'<<goto "Prosthetics Configuration">>';
 			} else {
-				s = `<<replace "#selector">><<= App.Desc.limbChange().reaction($activeSlave, ${JSON.stringify(oldLimbs)}, "${returnTo}")>><</replace>>`;
+				s = `<<replace "#selector">><<= App.Desc.limbChange().reaction(getSlave($AS), ${JSON.stringify(oldLimbs)}, "${returnTo}")>><</replace>>`;
 			}
 
-			return `<<link "Apply">><<run App.Desc.limbChange().applySelector($activeSlave, _newState)>>${s}<</link>>`;
+			return `<<link "Apply">><<run App.Desc.limbChange().applySelector(getSlave($AS), _newState)>>${s}<</link>>`;
 		}
 	}
@@ -106,7 +106,7 @@ App.Desc.limbChange = function() {
 
 	/**
-	 * Displays a selector for prosthetic limbs of $activeSlave
+	 * Displays a selector for prosthetic limbs of getSlave($AS)
 	 * @param {App.Entity.SlaveState} slave
 	 * @param {{}} oldLimbs